      SUBROUTINE CHECK_INITIAL(NX,NY,NSOLD,LAND_SEA,T1,STC,SMC,SH2O,CMC,
     &     SNOWH,SNEQV,SOILTYP,VEGTYP,SLOPETYP,TBOT,ALBEDO,SHDFAC,
     &     NSOIL,NMONTH,SOILDEPTH,CH,CM)

      IMPLICIT NONE

C     READS INITIAL CONDITIONS

      INTEGER NX
      INTEGER NY
      INTEGER NSOLD
      INTEGER NMONTH
      INTEGER LAND_SEA(NX,NY)
      INTEGER SOILTYP(NX,NY)
      INTEGER VEGTYP(NX,NY)
      INTEGER SLOPETYP(NX,NY)
      INTEGER NSOIL(NX,NY)

      REAL    T1(NX,NY)
      REAL    SOILDEPTH(NSOLD,NX,NY)
      REAL    STC(NSOLD,NX,NY)
      REAL    SMC(NSOLD,NX,NY)
      REAL    SH2O(NSOLD,NX,NY)
      REAL    CMC(NX,NY)
      REAL    SNOWH(NX,NY)
      REAL    SNEQV(NX,NY)
      REAL    CH(NX,NY)
      REAL    CM(NX,NY)

      REAL    TBOT(NX,NY)
      REAL    ALBEDO(NMONTH,NX,NY)
      REAL    SHDFAC(NMONTH,NX,NY)

      REAL    MAXSMC(9)
      REAL    WLTSMC(9)
      REAL    MAX_M, MIN_M

      INTEGER I, J, K

      DATA MAXSMC/0.421, 0.464, 0.468, 0.434, 0.406, 0.465, 0.404,
     &     0.439, 0.421/
      DATA WLTSMC/0.029, 0.119, 0.139, 0.047, 0.020, 0.103, 0.069,
     &     0.066, 0.029/

      DO J = 1,NY
         DO I = 1,NX
            IF (LAND_SEA(I,J) .EQ. 1) THEN
               
               IF (SOILTYP(I,J) .LE. 0) THEN
                  WRITE(*,*) 'SOILTYP is smaller than 1, ', I, J
                  SOILTYP(I,J) = 2
               END IF
               IF (SOILTYP(I,J) .GE. 10) THEN
                  WRITE(*,*) 'SOILTYP is larger than 10, ', I, J
                  SOILTYP(I,J) = 2
               END IF
               MAX_M = MAXSMC(SOILTYP(I,J))
               MIN_M = WLTSMC(SOILTYP(I,J))
               
               IF (VEGTYP(I,J) .LE. 0) THEN
                  WRITE(*,*) 'VEGTYP is smaller than 1, ', I, J
                  VEGTYP(I,J) = 7
               END IF
               IF (VEGTYP(I,J) .GE. 14) THEN
                  WRITE(*,*) 'VEGTYP is larger than 13, ', I, J
                  VEGTYP(I,J) = 7
               END IF
               
               IF (SLOPETYP(I,J) .LE. 0) THEN
                  WRITE(*,*) 'SLOPETYP is smaller than 1, ', I, J
                  SLOPETYP(I,J) = 1
               END IF
               IF (SLOPETYP(I,J) .GE. 10) THEN
                  WRITE(*,*) 'SLOPETYP is larger than 9, ', I, J
                  SLOPETYP(I,J) = 1
               END IF
               
               IF (TBOT(I,J) .LT. 230.0) THEN
                  TBOT(I,J) = 230.0
                  WRITE(*,*) 'Warning TBOT < 230.0K at ', I, J 
               END IF
               IF (TBOT(I,J) .GT. 350.0) THEN
                  TBOT(I,J) = 350.0
                  WRITE(*,*) 'Warning TBOT > 350.0K at ', I, J 
               END IF
               
               DO K = 1, NMONTH
                  IF (ALBEDO(K,I,J) .LT. 0.0) THEN
                     ALBEDO(K,I,J) = 0.0
                     WRITE(*,*) 'Warning ALBEDO < 0.0 at ', I, J 
                  END IF
                  IF (ALBEDO(K,I,J) .GT. 1.0) THEN
                     ALBEDO(K,I,J) = 1.0
                     WRITE(*,*) 'Warning ALBEDO > 1.0 at ', I, J 
                  END IF
                  
                  IF (SHDFAC(K,I,J) .LT. 0.0) THEN
                     SHDFAC(K,I,J) = 0.0
                     WRITE(*,*) 'Warning SHDFAC < 0.0 at ', I, J 
                  END IF
                  IF (SHDFAC(K,I,J) .GT. 1.0) THEN
                     SHDFAC(K,I,J) = 1.0
                     WRITE(*,*) 'Warning SHDFAC > 1.0 at ', I, J 
                  END IF
               END DO

               IF (NSOIL(I,J) .LT. 1) THEN
                  NSOIL(I,J) = 4
                  WRITE(*,*) 'Warning NSOIL < 1 at ', I, J 
               END IF
               IF (NSOIL(I,J) .GT. NSOLD) THEN
                  NSOIL(I,J) = NSOLD
                  WRITE(*,*) 'Warning NSOIL >',NSOLD,' at ', I, J 
               END IF

               IF (T1(I,J) .LT. 200.0) THEN
                  WRITE(*,*) 'Warning T1 < 200.0K at ', I, J, T1(I,J) 
                  T1(I,J) = 200.0
               END IF
               IF (T1(I,J) .GT. 400.0) THEN
                  T1(I,J) = 400.0
                  WRITE(*,*) 'Warning T1 > 400.0K at ', I, J 
               END IF
               DO K = 1, NSOLD
                  IF (STC(K,I,J) .LT. 230.0) THEN
                     STC(K,I,J) = 230.0
                     WRITE(*,*) 'Warning STC(',K,') < 230.0K at ', I, J 
                  END IF
                  IF (STC(K,I,J) .GT. 350.0) THEN
                     STC(K,I,J) = 350.0
                     WRITE(*,*) 'Warning STC(',K,') > 350.0K at ', I, J 
                  END IF
               END DO
               DO K = 1, NSOLD
                  IF (SMC(K,I,J) .LT. MIN_M) THEN
                     SMC(K,I,J) = MIN_M
C                     WRITE(*,*) 'Warning SMC(',K,') <',MIN_M,' at ',I,J 
                  END IF
                  IF (SMC(K,I,J) .GT. MAX_M) THEN
                     SMC(K,I,J) = MAX_M
C                     WRITE(*,*) 'Warning SMC(',K,') >',MAX_M,' at ',I,J 
                  END IF
               END DO
               DO K = 1, NSOLD
                  IF (SH2O(K,I,J) .LT. MIN_M) THEN
                     SH2O(K,I,J) = MIN_M
C                     WRITE(*,*) 'Warning SH2O(',K,') <',MIN_M,'at ',I,J 
                  END IF
                  IF (SH2O(K,I,J) .GT. MAX_M) THEN
                     SH2O(K,I,J) = MAX_M
C                     WRITE(*,*) 'Warning SH2O(',K,') >',MAX_M,'at ',I,J 
                  END IF
               END DO

               DO K = 1, NSOLD
                  IF (SOILDEPTH(K,I,J) .LT. 0.0) THEN
                     WRITE(*,*) 'SOILDEPTH(',K,') < 0.0)'
                     PAUSE
                  END IF
               END DO
               IF (CMC(I,J) .LT. 0.0) THEN
                  CMC(I,J) = 0.0
                  WRITE(*,*) 'Warning CMC < 0.0mm at ', I, J 
               END IF
               IF (CMC(I,J) .GT. 2.0) THEN
                  CMC(I,J) = 2.0
                  WRITE(*,*) 'Warning CMC > 2.0mm at ', I, J 
               END IF
               IF (SNOWH(I,J) .LT. 0.0) THEN
                  SNOWH(I,J) = 0.0
                  WRITE(*,*) 'Warning SNOWH < 0.0m at ', I, J 
               END IF
               IF (SNOWH(I,J) .GT. 100.0) THEN
                  SNOWH(I,J) = 100.0
                  WRITE(*,*) 'Warning SNOWH > 100.0m at ', I, J 
               END IF
               IF (SNEQV(I,J) .LT. 0.0) THEN
                  SNEQV(I,J) = 0.0
                  WRITE(*,*) 'Warning SNEQV < 0.0m at ', I, J 
               END IF
               IF (SNEQV(I,J) .GT. 20.0) THEN
                  SNEQV(I,J) = 20.0
                  WRITE(*,*) 'Warning SNEQV > 20.0m at ', I, J 
               END IF
               IF (CH(I,J) .LT. 0.0) THEN
                  CH(I,J) = 0.001
                  WRITE(*,*) 'Warning CH < 0.0 at ', I, J 
               END IF
               IF (CM(I,J) .LT. 0.0) THEN
                  CM(I,J) = 0.001
                  WRITE(*,*) 'Warning CM < 0.0 at ', I, J 
               END IF
            END IF
         END DO
      END DO
         
      END
