      SUBROUTINE GRIBOUT(NX,NY,LDASMASK,NSOLD,HOUR,YESTERDAY,
     &        BEFOREYESTER,NSWRS,NLWRS,LHTFL,SHTFL,GFLUX, 
     &        DSWRF,DLWRF,ARAIN,EVP,SSRUN,BGRUN,AVSFT,ALBDO,  
     &        WEASD,CWAT,SOILT,SOILM,LSOIL,PEVPR,VEG,SNOD,DUMMY)

C***********************************************************************
C  PROGRAM:  GRIBLDAS           WRITE LDAS OUTPUT IN GRIB FORMAT
C  PRGMMR:  MARSHALL & LOHMANN  ORG:  W/NP20
C
C  ABSTRACT:  TAKES HOURLY OUTPUT FILES FROM LDAS MODELS (IN BINARY
C             FORMAT - BIG ENDIAN) AND MAKES GRIB RECORDS FOR ALL FIELDS
C             IN THE FILE.  NOTE ORDER OF FIELDS IN EACH BINARY FILE
C             MUST CORRESPOND TO ORDER OF FIELDS IN KPDS.tbl.  TIME
C             STAMP INFORMATION MUST ALSO APPEAR (YYYYMMDDHH) IN THE
C             TITLE OF EACH BINARY HOURLY OUTPUT FILE.  THIS INFO IS
C             USED IN CONSTRUCTING THE TIME-RELATED PDS OCTETS WHICH
C             DO NOT APPEAR IN KPDS.tbl   
C
C  PROGRAM HISTORY LOG:
C  00-10-15 MARSHALL ORIGINAL TEMPLATE FOR NOAH MODEL
C  00-11-01 LOHMANN  FINALIZED AND CHANGED TO SUBROUTINE
C***********************************************************************

      IMPLICIT NONE

      INTEGER NX
      INTEGER NY
      INTEGER NSOLD

      CHARACTER*8 YESTERDAY, BEFOREYESTER

      REAL    NSWRS(NX,NY) 
      REAL    NLWRS(NX,NY)
      REAL    LHTFL(NX,NY) 
      REAL    SHTFL(NX,NY) 
      REAL    GFLUX(NX,NY) 
      REAL    DSWRF(NX,NY)
      REAL    DLWRF(NX,NY)
      REAL    ARAIN(NX,NY)
      REAL    EVP(NX,NY)
      REAL    SSRUN(NX,NY)
      REAL    BGRUN(NX,NY) 
      REAL    AVSFT(NX,NY)
      REAL    ALBDO(NX,NY) 
      REAL    WEASD(NX,NY)
      REAL    CWAT(NX,NY)
      REAL    SOILT(NSOLD,NX,NY)
      REAL    SOILM(NSOLD,NX,NY)
      REAL    LSOIL(NSOLD,NX,NY)
      REAL    PEVPR(NX,NY)
      REAL    VEG(NX,NY)
      REAL    LAI(NX,NY)
      REAL    SNOD(NX,NY)

      REAL    DUMMY(NX,NY)

      INTEGER HOUR

      INTEGER LUGB, I, J, K, N, IRET, KPDS(25), KGDS(22),
     &        NLDAS, LENGDS, IG, JRET, NFIELDS

      LOGICAL*1  LDASMASK(NX,NY)

      CHARACTER CENT*2, CHOUR*2, GDS(400), GRIBFILE*256

C     NON-CHANGING PDS ELEMENTS

      KPDS(1)=7                 !ID FOR NCEP PRODUCTS
      KPDS(2)=221               !ID FOR NOAH MODEL (change value for other models)
      KPDS(4)=192               !BMS FLAG... don't worry about this.
      KPDS(12)=0                !assume output time minute always = 0
      KPDS(13)=1                !hourly output
      KPDS(17)=4                !number of time steps in hourly averaged variables
      KPDS(18)=0                !GRIB version -- left as 0 in NCEP products
      KPDS(19)=1                !version number of KPDS.tbl for LDAS.  
      KPDS(20)=0                !none missing from averages/accumulations (always4)
      KPDS(23)=4                !EMC ID#
      KPDS(24)=0                !does not apply to LDAS output
      KPDS(25)=0                !not used

C     DEFINE THE GDS FOR THE LDAS GRID (THIS ARRAY NEVER CHANGES FROM
C     FIELD TO FIELD. ONLY HAS TO BE DEFINED ONCE, UNLIKE THE PDS).

      IG = 236    !FOR LDAS GRID IN SUBROUTINE w3fi71.f in w3lib

      CALL MAKGDS(IG, KGDS, GDS, LENGDS, IRET)

C     read past header info in KPDS.tbl
      OPEN (UNIT = 30, FILE = 'KPDS.tbl') 
      DO K = 1, 42
         READ(30,*)
      END DO

C     MAKE OUTPUT FILENAME
      IF (HOUR .LE. 11) THEN
         WRITE (CHOUR, '(i2.2)') HOUR + 12
         GRIBFILE = BEFOREYESTER//CHOUR//'_NOAH.LDASGRIB'//char(0)
      ELSE 
         WRITE (CHOUR, '(i2.2)') HOUR - 12
         GRIBFILE = YESTERDAY//CHOUR//'_NOAH.LDASGRIB'//char(0)
      END IF

C     OPEN GRIB FILE

      LUGB = 40
      CALL BAOPEN (LUGB, GRIBFILE, IRET)

C     WRITE EACH FIELD (IN GRIB) TO HOURLY OUTPUT FIELD
 15   FORMAT (29x, 7I6) 

      NLDAS = NX * NY

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,NSWRS,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = NSWRS'
         STOP
      ELSE
         PRINT*, 'wrote NSWRS'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,NLWRS,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = NLWRS'
         STOP
      ELSE
         PRINT*, 'wrote NLWRS'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,LHTFL,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = LHTFL'
         STOP
      ELSE
         PRINT*, 'wrote LHTFL'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,SHTFL,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = SHTFL'
         STOP
      ELSE
         PRINT*, 'wrote SHTFL'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,GFLUX,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = GFLUX'
         STOP
      ELSE
         PRINT*, 'wrote GFLUX'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,DSWRF,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = DSWRF'
         STOP
      ELSE
         PRINT*, 'wrote DSWRF'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,DLWRF,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = DLWRF'
         STOP
      ELSE
         PRINT*, 'wrote DLWRF'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,ARAIN,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = ARAIN'
         STOP
      ELSE
         PRINT*, 'wrote ARAIN'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,EVP,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = EVP'
         STOP
      ELSE
         PRINT*, 'wrote EVP'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,SSRUN,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = BGRUN'
         STOP
      ELSE
         PRINT*, 'wrote BGRUN'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,AVSFT,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = AVSFT'
         STOP
      ELSE
         PRINT*, 'wrote AVSFT'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,ALBDO,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = ALBDO'
         STOP
      ELSE
         PRINT*, 'wrote ALBDO'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,WEASD,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = WEASD'
         STOP
      ELSE
         PRINT*, 'wrote WEASD'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,CWAT,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = CWAT'
         STOP
      ELSE
         PRINT*, 'wrote CWAT'
      END IF

      DO N = 1, NSOLD
         DO J = 1,NY
            DO I = 1,NX
               DUMMY(I,J) = SOILT(N,I,J)
            END DO
         END DO
         READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +        KPDS(15), KPDS(16), KPDS(22)
C        MAKE TIME DEPENDENT PDS PARAMETERS
         CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
         CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,DUMMY,IRET)
         IF (IRET .NE. 0) THEN
            PRINT*, 'PUTGB FAILED FOR HOUR=',HOUR,',','FIELD = SOILT',N
            STOP
         ELSE
            PRINT*, 'wrote SOILT ', N
         END IF
      END DO

      DO N = 1, NSOLD
         DO J = 1,NY
            DO I = 1,NX
               DUMMY(I,J) = SOILM(N,I,J)
            END DO
         END DO
         READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +        KPDS(15), KPDS(16), KPDS(22)
C        MAKE TIME DEPENDENT PDS PARAMETERS
         CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
         CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,DUMMY,IRET)
         IF (IRET .NE. 0) THEN
            PRINT*, 'PUTGB FAILED FOR HOUR=',HOUR,',','FIELD = SOILM',N
            STOP
         ELSE
            PRINT*, 'wrote SOILM ',N
         END IF
      END DO

      DO N = 1, NSOLD
         DO J = 1,NY
            DO I = 1,NX
               DUMMY(I,J) = LSOIL(N,I,J)
            END DO
         END DO
         READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +        KPDS(15), KPDS(16), KPDS(22)
C        MAKE TIME DEPENDENT PDS PARAMETERS
         CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
         CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,DUMMY,IRET)
         IF (IRET .NE. 0) THEN
            PRINT*, 'PUTGB FAILED FOR HOUR=',HOUR,',','FIELD = LSOIL',N
            STOP
         ELSE
            PRINT*, 'wrote LSOIL ', N
         END IF
      END DO

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,PEVPR,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = PEVPR'
         STOP
      ELSE
         PRINT*, 'wrote PEVPR'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,VEG,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = VEG'
         STOP
      ELSE
         PRINT*, 'wrote VEG'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,LAI,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = LAI'
         STOP
      ELSE
         PRINT*, 'wrote LAI'
      END IF

      READ (30, 15) KPDS(5), KPDS(6), KPDS(7), KPDS(14), 
     +              KPDS(15), KPDS(16), KPDS(22)
C     MAKE TIME DEPENDENT PDS PARAMETERS
      CALL MAKEPDS(YESTERDAY, BEFOREYESTER, KPDS, HOUR)
      CALL PUTGB(LUGB,NLDAS,KPDS,KGDS,LDASMASK,SNOD,IRET)
      IF (IRET .NE. 0) THEN
         PRINT*, 'PUTGB FAILED FOR HOUR = ',HOUR,',','FIELD = SNOD'
      ELSE
         PRINT*, 'wrote SNOD'
         STOP
      END IF

      CALL BACLOSE (LUGB, JRET)
      CLOSE (30)

      END
